# PULib - Positive Unlabeled Library (Python 3)

Positive-Negative-Unlabeled machine learning library made with Python 3

- Can be used for train and test data PNU fit
- Can be used for model comparison (between Logistic Regression models and Positive-Negative-Unlabeled models, for example)
